pub struct VerifiedStorageQuote {
pub quote: BrowserQuoteArtifact,
pub quote_hash: String,
pub rewards_address: String,
pub amount: String,
}Expand description
A quote that is safe to hand to a transaction signer.
Fields
quote: BrowserQuoteArtifactOriginal verified quote sent back to the selected storage nodes.
quote_hash: StringLowercase EVM quote hash without 0x.
rewards_address: StringChecksummed-independent lowercase rewards address with 0x.
amount: StringDecimal amount paid after applying Autonomi’s replication multiplier.