pub struct BrowserEndpoint {
pub multiaddr: String,
}Expand description
Manifest- and wire-compatible wrapper around a WebRTC Direct multiaddress.
Fields
multiaddr: String/ip4|ip6/.../udp/.../webrtc-direct/certhash/.../p2p/... address.
Implementations
Sourceimpl BrowserEndpoint
impl BrowserEndpoint
Sourcepub fn new(
advertised_addr: SocketAddr,
peer_id: &[u8; 32],
certificate_hash: [u8; 32],
) -> Result<BrowserEndpoint, BrowserProtocolError>
pub fn new( advertised_addr: SocketAddr, peer_id: &[u8; 32], certificate_hash: [u8; 32], ) -> Result<BrowserEndpoint, BrowserProtocolError>
Construct the canonical endpoint form used by manifests and RPCs.
Errors
Returns an error when advertised_addr uses port zero.
Sourcepub fn parse(&self) -> Result<WebRtcDirectEndpoint, BrowserProtocolError>
pub fn parse(&self) -> Result<WebRtcDirectEndpoint, BrowserProtocolError>
Parse this endpoint into portable address components.
Errors
Returns an error when the endpoint is not canonical and fully pinned.