Module data

Module data 

Data operations for the Autonomi decentralized network.

Provides high-level APIs for storing and retrieving data using post-quantum cryptography.

Re-exports

pub use client::cache::ChunkCache;
pub use client::chunk::PeerPool;
pub use client::Client;
pub use client::ClientConfig;
pub use error::Error;
pub use error::Result;
pub use network::Network;
pub use client::batch::finalize_batch_payment;
pub use client::batch::PaidChunk;
pub use client::batch::PaymentIntent;
pub use client::batch::PreparedChunk;
pub use client::data::DataUploadResult;
pub use client::file::DownloadEvent;
pub use client::file::ExternalPaymentInfo;
pub use client::file::FileUploadResult;
pub use client::file::PreparedUpload;
pub use client::file::UploadCostEstimate;
pub use client::file::UploadEvent;
pub use client::file::Visibility;
pub use client::merkle::finalize_merkle_batch;
pub use client::merkle::MerkleBatchPaymentResult;
pub use client::merkle::PaymentMode;
pub use client::merkle::PreparedMerkleBatch;
pub use client::merkle::DEFAULT_MERKLE_THRESHOLD;
pub use crate::datamap_file::datamap_filename_for;
pub use crate::datamap_file::original_name_from_datamap;
pub use crate::datamap_file::read_datamap;
pub use crate::datamap_file::write_datamap;
pub use crate::datamap_file::CollisionPolicy;
pub use crate::datamap_file::DATAMAP_EXTENSION;

Modules

client
Client operations for the Autonomi network.
error
Error types for data operations.
network
Network layer wrapping ant-node’s P2P node.

Structs

CoreNodeConfig
Configuration for a P2P node
CustomNetwork
DataChunk
A chunk of data with its content-addressed identifier.
DataMap
Holds the information that is required to recover the content of the encrypted file. This is held as a vector of ChunkInfo, i.e. a list of the file’s chunk hashes. Only files larger than 3072 bytes (3 * MIN_CHUNK_SIZE) can be self-encrypted. Smaller files will have to be batched together.
DevnetManifest
Devnet manifest for client discovery.
IPDiversityConfig
Configuration for IP diversity enforcement at two tiers: exact IP and subnet.
MultiAddr
Composable, self-describing network address with an optional PeerId suffix.
P2PNode
Main P2P network node that manages connections, routing, and communication
Wallet

Enums

EvmNetwork
NodeMode
Operating mode of a P2P node.

Constants

MAX_CHUNK_SIZE
Maximum chunk size in bytes (4MB).
MAX_WIRE_MESSAGE_SIZE
Maximum wire message size in bytes (5MB).

Functions

compute_address
Compute the content address (BLAKE3 hash) for the given data.

Type Aliases

EvmAddress
U256
XorName
Content-addressed identifier (32 bytes).