pub struct ChannelMax {
pub quote: usize,
pub store: usize,
pub fetch: usize,
}Expand description
Per-channel concurrency ceilings. Each channel has its own cap so that constraining one (e.g. user pinned a low store concurrency for a slow uplink) never bleeds into another (download).
Fields
quote: usizestore: usizefetch: usizeTrait Implementations
Sourceimpl Clone for ChannelMax
impl Clone for ChannelMax
Sourcefn clone(&self) -> ChannelMax
fn clone(&self) -> ChannelMax
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelMax
impl Debug for ChannelMax
Sourceimpl Default for ChannelMax
impl Default for ChannelMax
Sourceimpl<'de> Deserialize<'de> for ChannelMax
impl<'de> Deserialize<'de> for ChannelMax
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ChannelMax
impl Serialize for ChannelMax
impl Copy for ChannelMax