Module batch

Module batch 

Batch chunk upload with wave-based pipelined EVM payments.

Groups chunks into waves of 64 and pays for each wave in a single EVM transaction. Stores from wave N are pipelined with quote collection for wave N+1 via tokio::join!.

Structs

PaidChunk
Chunk paid but not yet stored. Produced by Client::batch_pay.
PaymentIntent
Payment data for external signing.
PreparedChunk
Chunk quoted but not yet paid. Produced by Client::prepare_chunk_payment.
WaveResult
Result of storing a wave of paid chunks, with retry tracking.

Functions

finalize_batch_payment
Finalize a batch payment using externally-provided transaction hashes.