Module data

Module data 

In-memory data operations using self-encryption.

Upload and download raw byte data. Content is encrypted via convergent encryption and stored as content-addressed chunks. Use this when you already have data in memory (e.g., Bytes). For file-based streaming uploads that avoid loading the entire file into memory, see the file module.

Structs

DataUploadResult
Result of an in-memory data upload: the DataMap needed to retrieve the data.