pub enum EvmNetwork {
ArbitrumOne,
ArbitrumSepoliaTest,
Custom(CustomNetwork),
}Variants
Implementations
Sourceimpl Network
impl Network
pub fn new(local: bool) -> Result<Network, Error>
pub fn new_custom( rpc_url: &str, payment_token_addr: &str, payment_vault_addr: &str, ) -> Network
pub fn identifier(&self) -> &str
pub fn rpc_url(&self) -> &Url
pub fn payment_token_address(&self) -> &Address
Sourcepub fn payment_vault_address(&self) -> &Address
pub fn payment_vault_address(&self) -> &Address
Unified payment vault address (handles both single-node and merkle payments).
Sourcepub fn estimate_merkle_payment_cost(
&self,
depth: u8,
pool_commitments: &[PoolCommitment],
) -> Uint<256, 4>
pub fn estimate_merkle_payment_cost( &self, depth: u8, pool_commitments: &[PoolCommitment], ) -> Uint<256, 4>
Estimate the cost of a Merkle tree batch locally.
Estimates the worst-case cost of a Merkle tree payment locally.
The Solidity contract charges median16(quotes) * (1 << depth) for the
winning pool. The only unknown is which pool wins, so the worst case is
the pool with the highest median(prices) * 2^depth. No on-chain call
is made.
Arguments
depth- The Merkle tree depthpool_commitments- Vector of pool commitments with prices (one per reward pool)
Returns
- Worst-case cost estimate in AttoTokens