Module node

Module node 

Modules

binary
daemon
events
process
registry
types

Functions

add_nodes
Add one or more nodes to the registry.
node_status_offline
Get the status of all registered nodes without the daemon.
remove_node
Remove a node from the registry.
reset
Reset all node state: remove all data directories, log directories, and clear the registry.