extract_zip

Function extract_zip 

pub fn extract_zip(
    data: &[u8],
    install_dir: &Path,
    binary_name: &str,
) -> Result<ExtractionResult>
Extract a .zip archive and return the path to a named binary.

Searches the archive for an entry whose file name matches binary_name (or binary_name.exe on Windows) and writes it to install_dir/. Also extracts bootstrap_peers.toml if found in the archive.