pub fn info(config: &DaemonConfig) -> DaemonInfoExpand description
Get daemon connection info for programmatic use.
Reads PID and port files and checks if the process is alive.
pub fn info(config: &DaemonConfig) -> DaemonInfoGet daemon connection info for programmatic use.
Reads PID and port files and checks if the process is alive.