pub async fn node_status(config: &DaemonConfig) -> Result<NodeStatusResult>Expand description
Get the status of all registered nodes via the daemon REST API.
pub async fn node_status(config: &DaemonConfig) -> Result<NodeStatusResult>Get the status of all registered nodes via the daemon REST API.