pub async fn run(config: DaemonConfig) -> Result<()>Expand description
Run the daemon in the foreground (the actual daemon process entry point).
Starts the HTTP server, sets up signal handling, and blocks until shutdown.
pub async fn run(config: DaemonConfig) -> Result<()>Run the daemon in the foreground (the actual daemon process entry point).
Starts the HTTP server, sets up signal handling, and blocks until shutdown.