pub enum NodeEvent {
NodeStarting {
node_id: u32,
},
NodeStarted {
node_id: u32,
pid: u32,
},
NodeStopping {
node_id: u32,
},
NodeStopped {
node_id: u32,
},
NodeCrashed {
node_id: u32,
exit_code: Option<i32>,
},
NodeRestarting {
node_id: u32,
attempt: u32,
},
NodeErrored {
node_id: u32,
message: String,
},
DownloadStarted {
version: String,
},
DownloadProgress {
bytes: u64,
total: u64,
},
DownloadComplete {
version: String,
path: PathBuf,
},
UpgradeScheduled {
node_id: u32,
pending_version: String,
},
NodeUpgraded {
node_id: u32,
old_version: String,
new_version: String,
},
}Expand description
Structured events emitted by the daemon supervisor and long-running operations.
Serialized to JSON for SSE streaming at GET /api/v1/events.
Variants
NodeStarting
NodeStarted
NodeStopping
NodeStopped
NodeCrashed
NodeRestarting
NodeErrored
DownloadStarted
DownloadProgress
DownloadComplete
UpgradeScheduled
Emitted when the supervisor detects that a node’s on-disk binary has been replaced by its auto-upgrade, ahead of the node process restarting.
NodeUpgraded
Emitted after the supervisor has respawned a node against its replaced binary and observed the new version.
Implementations