Module chunk

Module chunk 

Chunk storage operations.

Chunks are immutable, content-addressed data blocks where the address is the BLAKE3 hash of the content.

Structs

ChunkPeerGetResult
Result of fetching one chunk address from one close-group peer.