Persistent client bootstrap peer cache.
Client peer IDs are ephemeral, so this cache is not keyed by distance from the local client. It remembers authenticated node peers that we have already connected to directly during client runs, stores their dialable channel addresses, and prefers retaining peers that are spread across the peer-id keyspace.
Enums
- Bootstrap
Address Filter - Address families allowed when materializing cached startup candidates.
Constants
Functions
- cache_
path - Build the on-disk cache path for the client peer cache.
- cached_
bootstrap_ peers - Load cache addresses to try before configured bootstrap peers.
- cached_
bootstrap_ peers_ with_ filter - Load cache addresses to try before configured bootstrap peers, applying an address-family filter before choosing the first address for each peer.
- promote_
connected_ direct_ peers - Persist authenticated peers reached directly during this client run.
- select_
bootstrap_ peers - Select startup bootstrap peers.