Modules
Functions
- add_
nodes - Add one or more nodes to the registry.
- node_
status_ offline - Get the status of all registered nodes without the daemon.
- remove_
node - Remove a node from the registry.
- reset
- Reset all node state: remove all data directories, log directories, and clear the registry.