pub fn extract_tar_gz(
data: &[u8],
install_dir: &Path,
binary_name: &str,
) -> Result<ExtractionResult>Expand description
Extract a .tar.gz archive and return the path to a named binary.
Searches the archive for an entry whose file name matches binary_name
and writes it to install_dir/<binary_name>. Also extracts bootstrap_peers.toml
if found in the archive.