Functions
- dismiss_
node - Dismiss a node — remove it from the registry — via the daemon REST API.
- fleet_
health - Get the current fleet health snapshot via the daemon REST API.
- info
- Get daemon connection info for programmatic use.
- log_
forward_ disable - Disable log forwarding via the daemon.
- log_
forward_ enable - Enable log forwarding via the daemon, so it starts shipping immediately.
- log_
forward_ status - Read the daemon’s log-forwarding status.
- node_
status - Get the status of all registered nodes via the daemon REST API.
- run
- Run the daemon in the foreground (the actual daemon process entry point).
- start
- Start the daemon as a detached background process.
- start_
all_ nodes - Start all registered nodes via the daemon REST API.
- start_
node - Start a specific node by ID via the daemon REST API.
- status
- Get the daemon’s current status by querying its REST API.
- stop
- Stop the running daemon.
- stop_
all_ nodes - Stop all running nodes via the daemon REST API.
- stop_
node - Stop a specific node by ID via the daemon REST API.