Skip to main contentModule client
Source - dismiss_node
- Dismiss a node — remove it from the registry — via the daemon REST API.
- fleet_health
- Get the current fleet health snapshot via the daemon REST API.
- info
- Get daemon connection info for programmatic use.
- node_status
- Get the status of all registered nodes via the daemon REST API.
- run
- Run the daemon in the foreground (the actual daemon process entry point).
- start
- Start the daemon as a detached background process.
- start_all_nodes
- Start all registered nodes via the daemon REST API.
- start_node
- Start a specific node by ID via the daemon REST API.
- status
- Get the daemon’s current status by querying its REST API.
- stop
- Stop the running daemon.
- stop_all_nodes
- Stop all running nodes via the daemon REST API.
- stop_node
- Stop a specific node by ID via the daemon REST API.