node_status_offline

Function node_status_offline 

pub fn node_status_offline(registry_path: &Path) -> Result<NodeStatusResult>
Get the status of all registered nodes without the daemon.

Since the daemon is not running, all nodes are reported as Stopped.