pub async fn spawn_node(
binary_path: &Path,
args: &[String],
env_vars: &[(String, String)],
log_dir: &Path,
) -> Result<Child>Expand description
Spawn a node process as a child of the current process (the daemon).
stdout and stderr are redirected to the given log directory.